@@ -90,12 +90,6 @@ impl Cache {
             ));
         }
 
-        if p.locked {
-            return Err(Error::FeatureError(
-                "Not support premium question for now".to_string(),
-            ));
-        }
-
         Ok(p)
     }
 
@@ -129,12 +123,6 @@ impl Cache {
             ));
         }
 
-        if target.locked {
-            return Err(Error::FeatureError(
-                "Not support premium question for now".to_string(),
-            ));
-        }
-
         let mut rdesc = Question::default();
         if !target.desc.is_empty() {
             rdesc = serde_json::from_str(&target.desc)?;
